# CodingCLI
This is a command line tool that helps you track your daily coding activities,using 
wakatime API 
## Pre-requisites
1. Sign up and login into the [wakatime](https://wakatime.com/signup) account.
2. From settings copy your wakatime api key.
## Installation 
To install CodingCLI run the following command in terminal 
```
pip install codingCLI

```
## Usage 
To know all the command line arguments supported by the CLI run following command :-
```
codingCLI -h

```
